@@ -69,6 +69,7 @@ class LuaScripts(object):
         KEYS[5]: the key for the profile id pool (ARGV[2])
         KEYS[6]: the key for new user detection
         KEYS[7]: the key for the stitch pool
+        KEYS[8]: temporary key to do some operations
         ARGV[1]: profile update info (ARGV[3])
         ARGV[2]: current timestamp (ARGV[4])
         ARGV[3]: session id (ARGV[5])
@@ -136,7 +137,7 @@ class LuaScripts(object):
                 redis.call('EXPIRE', KEYS[7], {user_ttl_with_margin})
             end
 
-            -- add user_hash_key. created and updated to profile
+            -- add user_hash_key, created, and updated to profile
             redis.call('HMSET', profile_key, '_user_hash', KEYS[1], '_updated', timestamp_now)
             if new_profile then
                 redis.call('HSET', profile_key, '_created', timestamp_now)
@@ -202,7 +203,27 @@ class LuaScripts(object):
                         end
                         local counter_data_str = cjson.encode(new_counter_data)
                         redis.call('HSET', p_key, v_key, counter_data_str)
-                    end      
+                    end    
+                elseif field_type == 'unqlist' then
+                    local max_length = tonumber(obj["mxl"])
+                    local end_index = max_length - 1
+                    local temp_key = KEYS[8]
+                    redis.call('ZADD', temp_key, unpack(cjson.decode(v)))
+                    if not current_value == false then
+                        local input_value = cjson.decode(current_value)
+                        if #input_value > 0 then
+                            redis.call('ZADD', temp_key, unpack(input_value))
+                        end
+                    end           
+                    local new_unique_data_rev = redis.call('ZREVRANGE', temp_key, 0, end_index, 'WITHSCORES')
+                    redis.call('DEL', temp_key)   
+                    local new_unique_data = {{}}
+                    for idx=1, #new_unique_data_rev, 2 do
+                        new_unique_data[idx] = new_unique_data_rev[idx+1]
+                        new_unique_data[idx+1] = new_unique_data_rev[idx]
+                    end
+                    local new_unique_data_str = cjson.encode(new_unique_data)
+                    redis.call('HSET', p_key, v_key, new_unique_data_str)
                 end 
             end
 
@@ -306,6 +327,10 @@ class LuaScripts(object):
             if profile_update.time_window30_counters ~= nil then
                 update_profile(profile_update.time_window30_counters, 'tw30count')
             end
+            
+            if profile_update.unique_lists ~= nil then
+                update_profile(profile_update.unique_lists, 'unqlist')
+            end
 
             -- add profile_key to sorted set of all profile keys
             redis.call('ZADD', KEYS[2], timestamp_now, profile_key)            
