@@ -295,6 +295,58 @@ class LargestValue(object):
             return self.copy_off(other, expire_at=expire_at)
         return self.copy_off(self, expire_at=expire_at)
 
+class UniqueValueList(ProfileProperty):
+
+    max_length = 50
+
+    @property
+    def output_value(self):
+
+        return [x[1] for x in self.current_value]
+
+    @classmethod
+    def value_from_redis(cls, value):
+        value = value.decode() if isinstance(value, bytes) else value
+        value = json.loads(value)
+        data = [(int(ts), str(val)) for ts, val in zip(value[::2], value[1::2])]
+        return cls._current_value(data)
+
+    @property
+    def current_value(self):
+        return self._current_value(value=self.value)
+
+    @classmethod
+    def _current_value(cls, value):
+        data = sorted(value, key=lambda x: x[0], reverse=True)
+        results = []
+        check = []
+        for ts, v in data:
+            if not v in check:
+                results.append((ts, v))
+                check.append(v)
+            if len(results) >= cls.max_length:
+                break
+        return sorted(results, key=lambda x: x[0])
+
+    def combine(self, other):
+
+        new_updated = max([self.updated, other.updated])
+        new_created = min([self.created, other.created])
+        new_expire_at = self.combine_expire(other)
+
+        new_value = self._current_value(self.current_value + other.current_value)
+
+        return self.__class__(self.name, new_value, updated=new_updated, created=new_created, expire_at=new_expire_at)
+
+    @classmethod
+    def value_to_redis(cls, value):
+
+        return json.dumps([x for entry in cls._current_value(value) for x in entry])
+
+    @property
+    def extra_redis_args(self):
+        return {
+            'mxl': self.max_length }
 
 class CounterWithTimeWindow(ProfileProperty):
 
@@ -372,6 +424,13 @@ class Counter(ProfileProperty, UsableProperty):
     py_key = 'counters'
     js_key = 'counters'
 
+class UniqueValueListMaxLength(UniqueValueList, UsableProperty):
+    type = list
+    prefix = 'uql_'
+    py_key = 'unique_lists'
+    js_key = 'uniqueLists'
+    max_length = 50
+
 class CounterWithTimeWindow30(CounterWithTimeWindow, UsableProperty):
     type = dict
     prefix = 'tmctr30_'
