@@ -386,13 +386,15 @@ class Profile(object):
     def get_stitched(cls,
                      user_ids,
                      time,
-                     fallback_to_db_lookup=False):
+                     fallback_to_db_lookup=False,
+                     force_db_lookup=False):
 
         profile_pool_keys = [cls._profile_pool_key(user_id) for user_id in user_ids]
         data = cls.redis_client.get_stitched_user_profile(keys=[], args=[json.dumps(profile_pool_keys), time.timestamp()])
         # a dictionary with profile_pool_key as key and corresponding (profile_key - profile) dict as value
         data_dict = {k.decode(): {pk.decode(): pr for pk, pr in dict(zip(v[::2], v[1::2])).items()} if v else None
                      for k, v in dict(zip(data[::2], data[1::2])).items()}
+        # incomplete users are users that have profile keys in their profile pool, whose profile is not present
         incomplete_users = {cls._user_id_from_profile_pool_key(k): v for k, v in data_dict.items() if not v or any(not bool(x) for x in v.values())}
         complete_users = {u:p for u,p in {cls._user_id_from_profile_pool_key(k): v for k, v in data_dict.items()}.items() if not u in incomplete_users}
 
@@ -402,14 +404,14 @@ class Profile(object):
 
         missing_users = []
 
-        if fallback_to_db_lookup:
+        if fallback_to_db_lookup or force_db_lookup:
 
             from_db = cls.from_database_by_user_ids(incomplete_users.keys())
             complemented_profiles = []
             for user_id, profiles_for_user in incomplete_users.items():
                 from_db_for_user = from_db.get(user_id, [])
                 if len(profiles_for_user) == 0:
-                    if len(from_db_for_user) ==0:
+                    if len(from_db_for_user) == 0:
                         missing_users.append(user_id)
                     else:
                         complemented_profiles.extend([cls.from_redis_data(profile.data,
@@ -620,7 +622,8 @@ class Profile(object):
                 self.new_profile_key,
                 self.profile_pool_key,
                 self.new_user_detected_key,
-                self.stitch_pool_key],
+                self.stitch_pool_key,
+                self.temp_key],
             args=[
                 self.lua_update_string,
                 self.time.timestamp(),
@@ -640,7 +643,7 @@ class Profile(object):
 
     @property
     def stitch_pool_key(self):
-
+        # this is also defined on the stitch pool class!
         return f'st:u:p:{self.domain}:{self.user_id}'
 
     def create_pointers(self, pointers):
@@ -843,6 +846,10 @@ class Profile(object):
     def profile_key(self):
         return self._profile_key(profile_id=self.profile_id)
 
+    @property
+    def temp_key(self):
+        return f'u:tmp:{str(uuid.uuid4())}'
+
     @classmethod
     def _profile_key(cls, profile_id):
         return f'u:p:{cls.domain}:{profile_id}'
